$(document).ready(function () {
	$.urlParam = function (name) {
		var results = new RegExp("[?&]" + name + "=([^&#]*)").exec(window.location.href);
		if (results != null) {
			return results[1];
		} else {
			return null;
		}
	};

	var defaultLeagueSn = 1;
	if ($.urlParam("leagueSn") != null) {
		defaultLeagueSn = $.urlParam("leagueSn");
	}

	var timeInMs = Date.now();

	$.getJSON("/basketball/jsons/seasons/" + defaultLeagueSn + "/seasonlist.json?nocache=" + timeInMs, function (data) {
		var seasonName = "";
		$.each(data, function (i, season) {
			if ($.urlParam("defaultSeasonSn") == season.sn) {
				var seasonNumber = new Number(season.name);
				if (isNaN(seasonNumber)) {
					seasonName = season.name;
				} else {
					seasonName = seasonNumber + " 學年度";
				}
			}
		});
		var navTemplate = $.templates("#navTemplate");
		var navTemplateData = {
			rosterSn: $.urlParam("rosterSn"),
			playerGrade: $.urlParam("playerGrade"),
			defaultSeason: $.urlParam("defaultSeasonSn"),
			seasonName: seasonName,
		};
		$("#nav").html(navTemplate.render(navTemplateData));
	});

	var rosterHeaderContent = "",
		rosterCurrentSeasonAverageStats = "";
	$.getJSON(
		"/basketball/jsons/rosters/" +
			$.urlParam("rosterSn") +
			"/rostergamerecordcareerseasonaveragae.json?nocache=" +
			timeInMs,
		function (data) {
			$.each(data, function (i, seasonAverageRecord) {
				if (seasonAverageRecord.season.sn == $.urlParam("defaultSeasonSn")) {
					var seasonName;
					var seasonNumber = new Number(seasonAverageRecord.season.name);
					if (isNaN(seasonNumber)) {
						seasonName = seasonAverageRecord.season.name;
					} else {
						seasonName = seasonNumber + " 學年度";
					}
					var template = $.templates("#rosterCurrentSeasonAverageStatsTemplate");
					var templateData = {
						seasonName: seasonName,
						seasonPoints: new Number(seasonAverageRecord.points).toFixed(1),
						seasonRebs: (
							new Number(seasonAverageRecord.defensiveRebound) + new Number(seasonAverageRecord.offensiveRebound)
						).toFixed(1),
						seasonAsts: new Number(seasonAverageRecord.assist).toFixed(1),
					};
					rosterCurrentSeasonAverageStats = template.render(templateData);
				}
			});
		}
	).always(function () {
		$.getJSON(
			"/basketball/jsons/rosters/" + $.urlParam("rosterSn") + "/rostergamerecordcareersummary.json?nocache=" + timeInMs,
			function (data) {
				var template = $.templates("#rosterTemplate");
				var rosterCareerAverageStatsTemplate = $.templates("#rosterCareerAverageStatsTemplate");
				var rosterCareerAverageStatsTemplateData = {
					careerPoints: new Number(data.seasonPoints / data.playedGames).toFixed(1),
					careerRebs: (
						(new Number(data.seasonDefensiveRebounds) + new Number(data.seasonOffensiveRebounds)) /
						data.playedGames
					).toFixed(1),
					careerAsts: new Number(data.seasonAssists / data.playedGames).toFixed(1),
				};
				var position = "";
				if (data.rosterPosition == "G") {
					position = "後衛";
				}
				if (data.rosterPosition == "F") {
					position = "前鋒";
				}
				if (data.rosterPosition == "C") {
					position = "中鋒";
				}
				var templateData = {
					rosterPic: data.rosterPic+ `?nocache=${timeInMs}`,
					rosterName: data.rosterName,
					position: position,
					height: data.rosterHeight,
					weight: data.rosterWeight,
					careerAverageStats: rosterCareerAverageStatsTemplate.render(rosterCareerAverageStatsTemplateData),
					currentSeasonAverageStats: rosterCurrentSeasonAverageStats,
				};
				rosterHeaderContent = template.render(templateData);
			}
		).always(function () {
			$("#rosterInfo").html(rosterHeaderContent);
		});
	});
	$.getJSON(
		"/basketball/jsons/rosters/" +
			$.urlParam("rosterSn") +
			"/records/" +
			$.urlParam("defaultSeasonSn") +
			"/gamerecord.json?nocache=" +
			timeInMs,
		function (data) {
			$("#seasonGameList").html("");
			var stageArray = [];
			var rosterRecordTemplate = $.templates("#rosterRecordsContentTemplate");
			$.each(data, function (i, gameRecord) {
				var rosterRecordHTML = "";
				var evenValue = "";
				if (i != 0 && i % 2 == 1) {
					evenValue = "even";
				}
				var fgm = gameRecord.twoPointsMade + gameRecord.threePointsMade;
				var fga =
					gameRecord.twoPointsMade +
					gameRecord.twoPointsMissed +
					gameRecord.threePointsMade +
					gameRecord.threePointsMissed;
				var threepa = gameRecord.threePointsMade + gameRecord.threePointsMissed;
				var fta = gameRecord.freethrowMade + gameRecord.freethrowMissed;
				var tot = gameRecord.offensiveRebound + gameRecord.defensiveRebound;
				var pts = gameRecord.twoPointsMade * 2 + gameRecord.threePointsMade * 3 + gameRecord.freethrowMade;
				var gameDate = new Date(gameRecord.game.playDate);
				var templateData = {
					even: evenValue,
					leagueSn: gameRecord.game.stage.season.league.sn,
					seasonSn: gameRecord.game.stage.season.sn,
					stageSn: gameRecord.game.stage.sn,
					groupSn: gameRecord.game.group.sn,
					gameSn: gameRecord.game.sn,
					playDate: gameDate.getFullYear() + "/" + (gameDate.getMonth() + 1) + "/" + gameDate.getDate(),
					teamHome: gameRecord.game.teamHome.name,
					teamGuest: gameRecord.game.teamGuest.name,
					playedMinutes: (gameRecord.playTime / 60).toFixed(0) + ":" + (gameRecord.playTime % 60).toFixed(0),
					points: pts,
					fieldGoalMade: fgm,
					fieldGoalAttempt: fga,
					fieldGoalPercentage: fga == 0 ? 0 : ((fgm / fga) * 100).toFixed(1),
					threePointsMade: gameRecord.threePointsMade,
					threePointsAttempt: threepa,
					threePointsPercentage: threepa == 0 ? 0 : ((gameRecord.threePointsMade / threepa) * 100).toFixed(1),
					freeThrowsMade: gameRecord.freethrowMade,
					freeThrowsAttempt: fta,
					freeThrowsPercentage: fta == 0 ? 0 : ((gameRecord.freethrowMade / fta) * 100).toFixed(1),
					offensiveRebounds: gameRecord.offensiveRebound,
					defensiveRebounds: gameRecord.defensiveRebound,
					totalRebounds: tot,
					asssits: gameRecord.assist,
					steals: gameRecord.steal,
					blocks: gameRecord.block,
					turnovers: gameRecord.turnover,
					personalFouls: gameRecord.personalFoul,
				};
				rosterRecordHTML += rosterRecordTemplate.render(templateData);
				for (var j = 0; j < stageArray.length; j++) {
					if (stageArray[j].stage.sn == gameRecord.game.stage.sn) {
						stageArray[j].rosterRecordHTML += rosterRecordHTML;
						break;
					} else {
						if (j == stageArray.length - 1) {
							stageArray.push({
								stage: gameRecord.game.stage,
								rosterRecordHTML: rosterRecordHTML,
							});
							break;
						}
					}
				}
				if (stageArray.length == 0) {
					stageArray.push({
						stage: gameRecord.game.stage,
						rosterRecordHTML: rosterRecordHTML,
					});
				}
			});
			for (var i = 0; i < stageArray.length; i++) {
				var tableTemplateData = {
					rosterRecordsContent: stageArray[i].rosterRecordHTML,
				};
				var stageTemplateData = {
					stageName: stageArray[i].stage.name,
					rosterRecodsTableContent: $.templates("#rosterTableHeaderAndFooterTemplate").render(tableTemplateData),
				};
				var rosterHTML = $.templates("#rosterRecordsHeaderAndFooterTemplate").render(stageTemplateData);
				$("#seasonGameList").append(rosterHTML);
			}
		}
	);
});
